(*

This program finds the stable arm using "backward shooting" and creates 
functions that will plot it, in 2 and 3 dimensions

*)

Print["Finding the stable arm."];
(* 

Given a current point, determine the previous point by running
the equations of motion for the system backwards.

*)

Clear[Devolve3D];
Devolve3D[DevolvingList_] := Block[{
	cOzPoint   = Last[DevolvingList][[1]],
	cdotOcPoint= Last[DevolvingList][[2]],
	kOzPoint   = Last[DevolvingList][[3]]
},
Return[Join[DevolvingList,{
{cOzPoint    - cOzAlldot[   cOzPoint,cdotOcPoint]/ScaleFactor,
 cdotOcPoint - cdotOcAlldot[cOzPoint,cdotOcPoint]/ScaleFactor,
 kOzPoint    - kOzAlldot[   cOzPoint,kOzPoint]   /ScaleFactor}}
]];
]

(*

Given an initial point, make a list of points on the stable arm by
devolving from a point epsilon away from the steady-state by running
the equations of motion backwards.  Quit when either 1) the list
is NumberOfSteps long; 2) the stable arm has gone outside of the
maximum or minimum allowable value for any one of the variables; or 3) the
distance between successive points is tiny

*)

ClearAll[DevolveSteps3D];
DevolveSteps3D[InitialList_,NumberOfSteps_] :=
Block[{DevolvingList = InitialList,TooLarge = False,TooSmall = False,WhichDimension = ""},
Do[
LastElement = Last[DevolvingList];
If[	Abs[Last[DevolvingList][[1]]] > cOzMaxDevolving     ,TooLarge = True; WhichDimension = "cOz"];
If[   	Abs[Last[DevolvingList][[2]]] > cdotOcMaxDevolving  ,TooLarge = True; WhichDimension = "cdotOc"];
If[	Abs[Last[DevolvingList][[3]]] > kOzMaxDevolving     ,TooLarge = True; WhichDimension = "kOz"];
If[	Abs[Last[DevolvingList][[1]]] < cOzMinDevolving     ,TooSmall = True; WhichDimension = "cOz"];
If[	Abs[Last[DevolvingList][[2]]] < cdotOcMinDevolving  ,TooSmall = True; WhichDimension = "cdotOc"];
If[	Abs[Last[DevolvingList][[3]]] < kOzMinDevolving     ,TooSmall = True; WhichDimension = "kOz"];

If[TooLarge == True,
  Print["Exiting DevolveSteps3D after "<>ToString[Length[DevolvingList]]<>" steps with last value "<>ToString[LastElement]
        <>" because "<>WhichDimension<>" exceeded "<>ToString[ToExpression[WhichDimension<>"MaxDevolving"]]<>"."];Break[]];
If[TooSmall == True,
  Print["Exiting DevolveSteps3D after "<>ToString[Length[DevolvingList]]<>" steps with last value "<>ToString[LastElement]
        <>" because "<>WhichDimension<>" fell below "<>ToString[ToExpression[WhichDimension<>"MinDevolving"]]<>"."];Break[]];
DevolvingList = Devolve3D[DevolvingList];
If[     Distance3D[Last[DevolvingList],LastElement] < SmallEnoughToQuit, (* then *) Break[]];
,{i,NumberOfSteps}];
Return[DevolvingList]];

DevolvPtsLeft3D  = DevolveSteps3D[{{cOzSS-epsilon,cdotOcSS,kOzSS-epsilon/100}},NumOfDevolvingPoints];
DevolvPtsRight3D = DevolveSteps3D[{{cOzSS+epsilon,cdotOcSS,kOzSS+epsilon/100}},NumOfDevolvingPoints];

TDevolvPtsLeft3D = Transpose[DevolvPtsLeft3D];

DevolvPtsLeftcOz      = TDevolvPtsLeft3D[[1]];
DevolvPtsLeftcdotOc   = TDevolvPtsLeft3D[[2]];
DevolvPtsLeftkOz      = TDevolvPtsLeft3D[[3]];
DevolvPtsLeftcOk      = TDevolvPtsLeft3D[[1]]/TDevolvPtsLeft3D[[3]];
DevolvPtsLeftkdotOk   = (A - delta) - DevolvPtsLeftcOk;
DevolvPtsLeftsOy      = 1- DevolvPtsLeftcOk/A;

DevolvPtsLeft3D     = Transpose[{DevolvPtsLeftcOz,DevolvPtsLeftcdotOc,DevolvPtsLeftkOz}];

DevolvLeftcOzMin       = Min[DevolvPtsLeftcOz];
DevolvLeftcOzMax       = Max[DevolvPtsLeftcOz];
DevolvLeftcdotOcMin    = Min[DevolvPtsLeftcdotOc];
DevolvLeftcdotOcMax    = Max[DevolvPtsLeftcdotOc];
DevolvLeftcOkMin       = Min[DevolvPtsLeftcOk];
DevolvLeftcOkMax       = Max[DevolvPtsLeftcOk];
DevolvLeftkOzMin       = Min[DevolvPtsLeftkOz];
DevolvLeftkOzMax       = Max[DevolvPtsLeftkOz];
DevolvLeftkOzAlldotMin = Min[DevolvPtsLeftkOzAlldot];
DevolvLeftkOzAlldotMax = Max[DevolvPtsLeftkOzAlldot];
DevolvLeftcdotOcAlldotMin = Min[DevolvPtsLeftcdotOcAlldot];
DevolvLeftcdotOcAlldotMax = Max[DevolvPtsLeftcdotOcAlldot];
DevolvLeftcdotOcAlldotMin = Min[DevolvPtsLeftcdotOcAlldot];
DevolvLeftcdotOcAlldotMax = Max[DevolvPtsLeftcdotOcAlldot];
DevolvLeftkdotOzMin    = Min[DevolvPtsLeftkdotOz];
DevolvLeftkdotOzMax    = Max[DevolvPtsLeftkdotOz];
DevolvLeftzdotOzMin    = Min[DevolvPtsLeftzdotOz];
DevolvLeftzdotOzMax    = Max[DevolvPtsLeftzdotOz];
DevolvLeftsOyMin       = Min[DevolvPtsLeftsOy];
DevolvLeftsOyMax       = Max[DevolvPtsLeftsOy];

DevolvPtsLeftcOzVScdotOc = Transpose[{DevolvPtsLeftcOz,DevolvPtsLeftcdotOc}];
DevolvPtsLeftcdotOcVScOk = Transpose[{DevolvPtsLeftcdotOc,DevolvPtsLeftcOk}];
DevolvPtsLeftcdotOcVScOz = Transpose[{DevolvPtsLeftcdotOc,DevolvPtsLeftcOz}];
DevolvPtsLeftcdotOcVSkOz = Transpose[{DevolvPtsLeftcdotOc,DevolvPtsLeftkOz}];
DevolvPtsLeftcOzVScOk    = Transpose[{DevolvPtsLeftcOz,DevolvPtsLeftcOk}];
DevolvPtsLeftcOzVSkOz    = Transpose[{DevolvPtsLeftcOz,DevolvPtsLeftkOz}];

DevolvPtsLeftkOzAlldot    = Map[kOzAlldotListForm,DevolvPtsLeftcOzVSkOz];
DevolvPtsLeftcdotOcAlldot = Map[cdotOcAlldotListForm,DevolvPtsLeftcOzVScdotOc];

(* Note that zdotOz = 1/(k/z) * (kdotOz - kOzAlldot) and kdotOz = kdotOk * kOz *)
DevolvPtsLeftkdotOz = DevolvPtsLeftkdotOk * DevolvPtsLeftkOz;
DevolvPtsLeftzdotOz = (1/DevolvPtsLeftkOz) (DevolvPtsLeftkdotOz - DevolvPtsLeftkOzAlldot);

DevolvPtsLeftkOzVScOz          = Transpose[{DevolvPtsLeftkOz,DevolvPtsLeftcOz}];
DevolvPtsLeftkOzVScdotOc       = Transpose[{DevolvPtsLeftkOz,DevolvPtsLeftcdotOc}];
DevolvPtsLeftkOzVSkOzAlldot    = Transpose[{DevolvPtsLeftkOz,DevolvPtsLeftkOzAlldot}];
DevolvPtsLeftkOzVSkdotOk       = Transpose[{DevolvPtsLeftkOz,DevolvPtsLeftkdotOk}];
DevolvPtsLeftkOzVSzdotOz       = Transpose[{DevolvPtsLeftkOz,DevolvPtsLeftzdotOz}];
DevolvPtsLeftkOzVScdotOcAlldot = Transpose[{DevolvPtsLeftkOz,DevolvPtsLeftcdotOcAlldot}];
DevolvPtsLeftkOzVSsOy          = Transpose[{DevolvPtsLeftkOz,DevolvPtsLeftsOy}];

Clear[DevolvFuncLeft2DcOzVScdotOc];
Clear[DevolvFuncLeft2DcdotOcVScOz];
Clear[DevolvFuncLeft2DcdotOcVScOk];
Clear[DevolvFuncLeft2DcdotOcVSkOz];
Clear[DevolvFuncLeft2DcOzVScOk];
Clear[DevolvFuncLeft2DcOzVSkOz];

Clear[DevolvFuncLeft2DkOzVScOz];
Clear[DevolvFuncLeft2DkOzVScdotOc];
Clear[DevolvFuncLeft2DkOzVSkOzAlldot];
Clear[DevolvFuncLeft2DkOzVSkdotOk];
Clear[DevolvFuncLeft2DkOzVSzdotOz];
Clear[DevolvFuncLeft2DkOzVScdotOcAlldot];
Clear[DevolvFuncLeft2DkOzVSsOy];

DevolvFuncLeft2DcOzVScdotOc = Interpolation[DevolvPtsLeftcOzVScdotOc];
DevolvFuncLeft2DcdotOcVScOk = Interpolation[DevolvPtsLeftcdotOcVScOk];
DevolvFuncLeft2DcdotOcVScOz = Interpolation[DevolvPtsLeftcdotOcVScOz];
DevolvFuncLeft2DcdotOcVSkOz = Interpolation[DevolvPtsLeftcdotOcVSkOz];
DevolvFuncLeft2DcOzVScOk    = Interpolation[DevolvPtsLeftcOzVScOk];
DevolvFuncLeft2DcOzVSkOz    = Interpolation[DevolvPtsLeftcOzVSkOz];
DevolvFuncLeft2DkOzVScOz    = Interpolation[DevolvPtsLeftkOzVScOz];

DevolvFuncLeft2DkOzVScOz          = Interpolation[DevolvPtsLeftkOzVScOz         ];
DevolvFuncLeft2DkOzVScdotOc       = Interpolation[DevolvPtsLeftkOzVScdotOc      ];
DevolvFuncLeft2DkOzVSkOzAlldot    = Interpolation[DevolvPtsLeftkOzVSkOzAlldot   ];
DevolvFuncLeft2DkOzVSkdotOk       = Interpolation[DevolvPtsLeftkOzVSkdotOk      ];
DevolvFuncLeft2DkOzVSzdotOz       = Interpolation[DevolvPtsLeftkOzVSzdotOz      ];
DevolvFuncLeft2DkOzVScdotOcAlldot = Interpolation[DevolvPtsLeftkOzVScdotOcAlldot];
DevolvFuncLeft2DkOzVSsOy          = Interpolation[DevolvPtsLeftkOzVSsOy];

TDevolvPtsRight3D = Transpose[DevolvPtsRight3D];

DevolvPtsRightcOz      = TDevolvPtsRight3D[[1]];
DevolvPtsRightcdotOc   = TDevolvPtsRight3D[[2]];
DevolvPtsRightkOz      = TDevolvPtsRight3D[[3]];
DevolvPtsRightcOk      = TDevolvPtsRight3D[[1]]/TDevolvPtsRight3D[[3]];
DevolvPtsRightkdotOk   = (A - delta) - DevolvPtsRightcOk;
DevolvPtsRightsOy      = 1- DevolvPtsRightcOk/A;

DevolvPtsRight3D     = Transpose[{DevolvPtsRightcOz,DevolvPtsRightcdotOc,DevolvPtsRightkOz}];

DevolvRightcOzMin       = Min[DevolvPtsRightcOz];
DevolvRightcOzMax       = Max[DevolvPtsRightcOz];
DevolvRightcdotOcMin    = Min[DevolvPtsRightcdotOc];
DevolvRightcdotOcMax    = Max[DevolvPtsRightcdotOc];
DevolvRightcOkMin       = Min[DevolvPtsRightcOk];
DevolvRightcOkMax       = Max[DevolvPtsRightcOk];
DevolvRightkOzMin       = Min[DevolvPtsRightkOz];
DevolvRightkOzMax       = Max[DevolvPtsRightkOz];
DevolvRightkOzAlldotMin = Min[DevolvPtsRightkOzAlldot];
DevolvRightkOzAlldotMax = Max[DevolvPtsRightkOzAlldot];
DevolvRightcdotOcAlldotMin = Min[DevolvPtsRightcdotOcAlldot];
DevolvRightcdotOcAlldotMax = Max[DevolvPtsRightcdotOcAlldot];
DevolvRightcdotOcAlldotMin = Min[DevolvPtsRightcdotOcAlldot];
DevolvRightcdotOcAlldotMax = Max[DevolvPtsRightcdotOcAlldot];
DevolvRightkdotOzMin    = Min[DevolvPtsRightkdotOz];
DevolvRightkdotOzMax    = Max[DevolvPtsRightkdotOz];
DevolvRightzdotOzMin    = Min[DevolvPtsRightzdotOz];
DevolvRightzdotOzMax    = Max[DevolvPtsRightzdotOz];
DevolvRightsOyMin       = Min[DevolvPtsRightsOy];
DevolvRightsOyMax       = Max[DevolvPtsRightsOy];

DevolvPtsRightcOzVScdotOc = Transpose[{DevolvPtsRightcOz,DevolvPtsRightcdotOc}];
DevolvPtsRightcdotOcVScOk = Transpose[{DevolvPtsRightcdotOc,DevolvPtsRightcOk}];
DevolvPtsRightcdotOcVScOz = Transpose[{DevolvPtsRightcdotOc,DevolvPtsRightcOz}];
DevolvPtsRightcdotOcVSkOz = Transpose[{DevolvPtsRightcdotOc,DevolvPtsRightkOz}];
DevolvPtsRightcOzVScOk    = Transpose[{DevolvPtsRightcOz,DevolvPtsRightcOk}];
DevolvPtsRightcOzVSkOz    = Transpose[{DevolvPtsRightcOz,DevolvPtsRightkOz}];

DevolvPtsRightkOzAlldot    = Map[kOzAlldotListForm,DevolvPtsRightcOzVSkOz];
DevolvPtsRightcdotOcAlldot = Map[cdotOcAlldotListForm,DevolvPtsRightcOzVScdotOc];

(* Note that zdotOz = 1/(k/z) * (kdotOz - kOzAlldot) and kdotOz = kdotOk * kOz *)
DevolvPtsRightkdotOz = DevolvPtsRightkdotOk * DevolvPtsRightkOz;
DevolvPtsRightzdotOz = (1/DevolvPtsRightkOz) (DevolvPtsRightkdotOz - DevolvPtsRightkOzAlldot);

DevolvPtsRightkOzVScOz          = Transpose[{DevolvPtsRightkOz,DevolvPtsRightcOz}];
DevolvPtsRightkOzVScdotOc       = Transpose[{DevolvPtsRightkOz,DevolvPtsRightcdotOc}];
DevolvPtsRightkOzVSkOzAlldot    = Transpose[{DevolvPtsRightkOz,DevolvPtsRightkOzAlldot}];
DevolvPtsRightkOzVSkdotOk       = Transpose[{DevolvPtsRightkOz,DevolvPtsRightkdotOk}];
DevolvPtsRightkOzVSzdotOz       = Transpose[{DevolvPtsRightkOz,DevolvPtsRightzdotOz}];
DevolvPtsRightkOzVScdotOcAlldot = Transpose[{DevolvPtsRightkOz,DevolvPtsRightcdotOcAlldot}];
DevolvPtsRightkOzVSsOy          = Transpose[{DevolvPtsRightkOz,DevolvPtsRightsOy      }];

Clear[DevolvFuncRight2DcOzVScdotOc];
Clear[DevolvFuncRight2DcdotOcVScOz];
Clear[DevolvFuncRight2DcdotOcVScOk];
Clear[DevolvFuncRight2DcdotOcVSkOz];
Clear[DevolvFuncRight2DcOzVScOk];
Clear[DevolvFuncRight2DcOzVSkOz];

Clear[DevolvFuncRight2DkOzVScOz];
Clear[DevolvFuncRight2DkOzVScdotOc];
Clear[DevolvFuncRight2DkOzVSkOzAlldot];
Clear[DevolvFuncRight2DkOzVSkdotOk];
Clear[DevolvFuncRight2DkOzVSzdotOz];
Clear[DevolvFuncRight2DkOzVScdotOcAlldot];
Clear[DevolvFuncRight2DkOzVSsOy];

DevolvFuncRight2DcOzVScdotOc = Interpolation[DevolvPtsRightcOzVScdotOc];
DevolvFuncRight2DcdotOcVScOk = Interpolation[DevolvPtsRightcdotOcVScOk];
DevolvFuncRight2DcdotOcVScOz = Interpolation[DevolvPtsRightcdotOcVScOz];
DevolvFuncRight2DcdotOcVSkOz = Interpolation[DevolvPtsRightcdotOcVSkOz];
DevolvFuncRight2DcOzVScOk    = Interpolation[DevolvPtsRightcOzVScOk];
DevolvFuncRight2DcOzVSkOz    = Interpolation[DevolvPtsRightcOzVSkOz];
DevolvFuncRight2DkOzVScOz    = Interpolation[DevolvPtsRightkOzVScOz];

DevolvFuncRight2DkOzVScOz          = Interpolation[DevolvPtsRightkOzVScOz         ];
DevolvFuncRight2DkOzVScdotOc       = Interpolation[DevolvPtsRightkOzVScdotOc      ];
DevolvFuncRight2DkOzVSkOzAlldot    = Interpolation[DevolvPtsRightkOzVSkOzAlldot   ];
DevolvFuncRight2DkOzVSkdotOk       = Interpolation[DevolvPtsRightkOzVSkdotOk      ];
DevolvFuncRight2DkOzVSzdotOz       = Interpolation[DevolvPtsRightkOzVSzdotOz      ];
DevolvFuncRight2DkOzVScdotOcAlldot = Interpolation[DevolvPtsRightkOzVScdotOcAlldot];
DevolvFuncRight2DkOzVSsOy          = Interpolation[DevolvPtsRightkOzVSsOy];

DevolvPtskOz          = Join[DevolvPtsLeftkOz,DevolvPtsRightkOz];
DevolvPtscOz          = Join[DevolvPtsLeftcOz,DevolvPtsRightcOz];
DevolvPtscdotOc       = Join[DevolvPtsLeftcdotOc,DevolvPtsRightcdotOc];
DevolvPtskOzAlldot    = Join[DevolvPtsLeftkOzAlldot,DevolvPtsRightkOzAlldot];
DevolvPtskdotOk       = Join[DevolvPtsLeftkdotOk,DevolvPtsRightkdotOk];
DevolvPtszdotOz       = Join[DevolvPtsLeftzdotOz,DevolvPtsRightzdotOz];
DevolvPtscdotOcAlldot = Join[DevolvPtsLeftcdotOcAlldot,DevolvPtsRightcdotOcAlldot];
DevolvPtssOy          = Join[DevolvPtsLeftsOy,DevolvPtsRightsOy];

DevolvPtscOk          = Join[DevolvPtsLeftcOk,DevolvPtsRightcOk];
DevolvPtskdotOk       = Join[DevolvPtsLeftkdotOk,DevolvPtsRightkdotOk];
DevolvPtssOy          = Join[DevolvPtsLeftsOy,DevolvPtsRightsOy];

MaxPtskOz           = Max[DevolvPtskOz         ];
MaxPtscOz           = Max[DevolvPtscOz         ];
MaxPtscdotOc        = Max[DevolvPtscdotOc      ];
MaxPtskOzAlldot     = Max[DevolvPtskOzAlldot   ];
MaxPtskdotOk        = Max[DevolvPtskdotOk      ];
MaxPtszdotOz        = Max[DevolvPtszdotOz      ];
MaxPtscdotOcAlldot  = Max[DevolvPtscdotOcAlldot];
MaxPtssOy           = Max[DevolvPtssOy         ];

MinPtskOz           = Min[DevolvPtskOz         ];
MinPtscOz           = Min[DevolvPtscOz         ];
MinPtscdotOc        = Min[DevolvPtscdotOc      ];
MinPtskOzAlldot     = Min[DevolvPtskOzAlldot   ];
MinPtskdotOk        = Min[DevolvPtskdotOk      ];
MinPtszdotOz        = Min[DevolvPtszdotOz      ];
MinPtscdotOcAlldot  = Min[DevolvPtscdotOcAlldot];
MinPtssOy           = Min[DevolvPtssOy         ];

DevolvPtscOzVScdotOc = Transpose[{DevolvPtscOz,DevolvPtscdotOc}];
DevolvPtscdotOcVScOk = Transpose[{DevolvPtscdotOc,DevolvPtscOk}];
DevolvPtscdotOcVScOz = Transpose[{DevolvPtscdotOc,DevolvPtscOz}];
DevolvPtscdotOcVSkOz = Transpose[{DevolvPtscdotOc,DevolvPtskOz}];
DevolvPtscOzVScOk    = Transpose[{DevolvPtscOz,DevolvPtscOk}];
DevolvPtscOzVSkOz    = Transpose[{DevolvPtscOz,DevolvPtskOz}];

DevolvPtskOzVScOz          = Sort[Join[DevolvPtsLeftkOzVScOz,DevolvPtsRightkOzVScOz]]                  ;
DevolvPtskOzVScdotOc       = Sort[Join[DevolvPtsLeftkOzVScdotOc,DevolvPtsRightkOzVScdotOc]]            ;
DevolvPtskOzVSkOzAlldot    = Sort[Join[DevolvPtsLeftkOzVSkOzAlldot,DevolvPtsRightkOzVSkOzAlldot]]      ;
DevolvPtskOzVSkdotOk       = Sort[Join[DevolvPtsLeftkOzVSkdotOk,DevolvPtsRightkOzVSkdotOk]]            ;
DevolvPtskOzVSzdotOz       = Sort[Join[DevolvPtsLeftkOzVSzdotOz,DevolvPtsRightkOzVSzdotOz]]            ;
DevolvPtskOzVScdotOcAlldot = Sort[Join[DevolvPtsLeftkOzVScdotOcAlldot,DevolvPtsRightkOzVScdotOcAlldot]];
DevolvPtskOzVSsOy          = Sort[Join[DevolvPtsLeftkOzVSsOy,DevolvPtsRightkOzVSsOy]]                  ;

Clear[DevolvFunc2DcOzVScdotOc ];
Clear[DevolvFunc2DcdotOcVScOk ];
Clear[DevolvFunc2DcdotOcVScOz ];
Clear[DevolvFunc2DcdotOcVSkOz ];
Clear[DevolvFunc2DcOzVScOk    ];
Clear[DevolvFunc2DcOzVSkOz    ];
Clear[DevolvFunc2DkOzVScOz    ];

DevolvFunc2DcOzVScdotOc = Interpolation[DevolvPtscOzVScdotOc];
DevolvFunc2DcdotOcVScOk = Interpolation[DevolvPtscdotOcVScOk];
DevolvFunc2DcdotOcVScOz = Interpolation[DevolvPtscdotOcVScOz];
DevolvFunc2DcdotOcVSkOz = Interpolation[DevolvPtscdotOcVSkOz];
DevolvFunc2DcOzVScOk    = Interpolation[DevolvPtscOzVScOk];
DevolvFunc2DcOzVSkOz    = Interpolation[DevolvPtscOzVSkOz];
DevolvFunc2DkOzVScOz    = Interpolation[DevolvPtskOzVScOz];

Clear[DevolvFunc2DkOzVScOz];
Clear[DevolvFunc2DkOzVScdotOc];
Clear[DevolvFunc2DkOzVSkOzAlldot];
Clear[DevolvFunc2DkOzVSkdotOk];
Clear[DevolvFunc2DkOzVSzdotOz];
Clear[DevolvFunc2DkOzVScdotOcAlldot];
Clear[DevolvFunc2DkOzVSsOy];

DevolvFunc2DkOzVScOz          = Interpolation[DevolvPtskOzVScOz         ];
DevolvFunc2DkOzVScdotOc       = Interpolation[DevolvPtskOzVScdotOc      ];
DevolvFunc2DkOzVSkOzAlldot    = Interpolation[DevolvPtskOzVSkOzAlldot   ];
DevolvFunc2DkOzVSkdotOk       = Interpolation[DevolvPtskOzVSkdotOk      ];
DevolvFunc2DkOzVSzdotOz       = Interpolation[DevolvPtskOzVSzdotOz      ];
DevolvFunc2DkOzVScdotOcAlldot = Interpolation[DevolvPtskOzVScdotOcAlldot];
DevolvFunc2DkOzVSsOy          = Interpolation[DevolvPtskOzVSsOy         ];
