(*

This program finds the stable arm for the decentralized economy and
creates functions that will plot it, in 2 and 3 dimensions

*)

(* 

Given a current point, determine the previous point by running
the equations of motion for the system backwards.

*)

Clear[Devolve3D];
Devolve3D[DevolvingList_] := Block[{
	cOzPoint   = Last[DevolvingList][[1]],
	cdotOcPoint= Last[DevolvingList][[2]],
	kOzPoint   = Last[DevolvingList][[3]]
},
Return[Join[DevolvingList,{
{cOzPoint    - cOzAlldot[   cOzPoint,cdotOcPoint]/ScaleFactor,
 cdotOcPoint - cdotOcAlldot[cOzPoint,cdotOcPoint]/ScaleFactor,
 kOzPoint    - kOzAlldot[   cOzPoint,kOzPoint]   /ScaleFactor}}
]];
]

(*

Given an initial point, make a list of points on the stable arm by
devolving from a point epsilon away from the steady-state by running
the equations of motion backwards.  Quit when either 1) the list
is NumberOfSteps long; 2) the stable arm has gone outside of the
maximum or minimum allowable value for any one of the axes; or 3) the
distance between successive points is tiny

*)

Clear[DevolveSteps3D];
DevolveSteps3D[InitialList_,NumberOfSteps_] :=
Block[{DevolvingList = InitialList,TooLarge = False,TooSmall = False,WhichDimension = ""},
Do[
LastElement = Last[DevolvingList];
If[	Abs[Last[DevolvingList][[1]]] > cOzMaxDevolving     ,TooLarge = True; WhichDimension = "cOz"];
If[   	Abs[Last[DevolvingList][[2]]] > cdotOcMaxDevolving  ,TooLarge = True; WhichDimension = "cdotOc"];
If[	Abs[Last[DevolvingList][[3]]] > kOzMaxDevolving     ,TooLarge = True; WhichDimension = "kOz"];
If[	Abs[Last[DevolvingList][[1]]] < cOzMinDevolving     ,TooSmall = True; WhichDimension = "cOz"];
If[	Abs[Last[DevolvingList][[2]]] < cdotOcMinDevolving  ,TooSmall = True; WhichDimension = "cdotOc"];
If[	Abs[Last[DevolvingList][[3]]] < kOzMinDevolving     ,TooSmall = True; WhichDimension = "kOz"];

If[TooLarge == True,
  Print["Exiting DevolveSteps3D after "<>ToString[Length[DevolvingList]]<>" steps with last value "<>ToString[LastElement]
        <>" because "<>WhichDimension<>" exceeded "<>ToString[ToExpression[WhichDimension<>"MaxDevolving"]]<>"."];Break[]];
If[TooSmall == True,
  Print["Exiting DevolveSteps3D after "<>ToString[Length[DevolvingList]]<>" steps with last value "<>ToString[LastElement]
        <>" because "<>WhichDimension<>" fell below "<>ToString[ToExpression[WhichDimension<>"MinDevolving"]]<>"."];Break[]];
DevolvingList = Devolve3D[DevolvingList];
If[     Distance3D[Last[DevolvingList],LastElement] < SmallEnoughToQuit, (* then *) Break[]];
,{i,NumberOfSteps}];
Return[DevolvingList]];

DDevolvPtsLeft3D  = DevolveSteps3D[{{cOzSS-epsilon,cdotOcSS,kOzSS-epsilon/100}},NumOfDevolvingPoints];
DDevolvPtsRight3D = DevolveSteps3D[{{cOzSS+epsilon,cdotOcSS,kOzSS+epsilon/100}},NumOfDevolvingPoints];

TDDevolvPtsLeft3D = Transpose[DDevolvPtsLeft3D];

DDevolvPtsLeftcOz      = TDDevolvPtsLeft3D[[1]];
DDevolvPtsLeftcdotOc   = TDDevolvPtsLeft3D[[2]];
DDevolvPtsLeftkOz      = TDDevolvPtsLeft3D[[3]];
DDevolvPtsLeftcOk      = TDDevolvPtsLeft3D[[1]]/TDDevolvPtsLeft3D[[3]];
DDevolvPtsLeftkdotOk   = (A - delta) - DDevolvPtsLeftcOk;
DDevolvPtsLeftsOy      = 1- DDevolvPtsLeftcOk/A;

DDevolvPtsLeft3D     = Transpose[{DDevolvPtsLeftcOz,DDevolvPtsLeftcdotOc,DDevolvPtsLeftkOz}];

DDevolvLeftcOzMin       = Min[DDevolvPtsLeftcOz];
DDevolvLeftcOzMax       = Max[DDevolvPtsLeftcOz];
DDevolvLeftcdotOcMin    = Min[DDevolvPtsLeftcdotOc];
DDevolvLeftcdotOcMax    = Max[DDevolvPtsLeftcdotOc];
DDevolvLeftcOkMin       = Min[DDevolvPtsLeftcOk];
DDevolvLeftcOkMax       = Max[DDevolvPtsLeftcOk];
DDevolvLeftkOzMin       = Min[DDevolvPtsLeftkOz];
DDevolvLeftkOzMax       = Max[DDevolvPtsLeftkOz];
DDevolvLeftkOzAlldotMin = Min[DDevolvPtsLeftkOzAlldot];
DDevolvLeftkOzAlldotMax = Max[DDevolvPtsLeftkOzAlldot];
DDevolvLeftcdotOcAlldotMin = Min[DDevolvPtsLeftcdotOcAlldot];
DDevolvLeftcdotOcAlldotMax = Max[DDevolvPtsLeftcdotOcAlldot];
DDevolvLeftcdotOcAlldotMin = Min[DDevolvPtsLeftcdotOcAlldot];
DDevolvLeftcdotOcAlldotMax = Max[DDevolvPtsLeftcdotOcAlldot];
DDevolvLeftkdotOzMin    = Min[DDevolvPtsLeftkdotOz];
DDevolvLeftkdotOzMax    = Max[DDevolvPtsLeftkdotOz];
DDevolvLeftzdotOzMin    = Min[DDevolvPtsLeftzdotOz];
DDevolvLeftzdotOzMax    = Max[DDevolvPtsLeftzdotOz];
DDevolvLeftsOyMin       = Min[DDevolvPtsLeftsOy];
DDevolvLeftsOyMax       = Max[DDevolvPtsLeftsOy];

DDevolvPtsLeftcOzVScdotOc = Transpose[{DDevolvPtsLeftcOz,DDevolvPtsLeftcdotOc}];
DDevolvPtsLeftcdotOcVScOk = Transpose[{DDevolvPtsLeftcdotOc,DDevolvPtsLeftcOk}];
DDevolvPtsLeftcdotOcVScOz = Transpose[{DDevolvPtsLeftcdotOc,DDevolvPtsLeftcOz}];
DDevolvPtsLeftcdotOcVSkOz = Transpose[{DDevolvPtsLeftcdotOc,DDevolvPtsLeftkOz}];
DDevolvPtsLeftcOzVScOk    = Transpose[{DDevolvPtsLeftcOz,DDevolvPtsLeftcOk}];
DDevolvPtsLeftcOzVSkOz    = Transpose[{DDevolvPtsLeftcOz,DDevolvPtsLeftkOz}];

DDevolvPtsLeftkOzAlldot    = Map[kOzAlldotListForm,DDevolvPtsLeftcOzVSkOz];
DDevolvPtsLeftcdotOcAlldot = Map[cdotOcAlldotListForm,DDevolvPtsLeftcOzVScdotOc];

(* Note that zdotOz = 1/(k/z) * (kdotOz - kOzAlldot) and kdotOz = kdotOk * kOz *)
DDevolvPtsLeftkdotOz = DDevolvPtsLeftkdotOk * DDevolvPtsLeftkOz;
DDevolvPtsLeftzdotOz = (1/DDevolvPtsLeftkOz) (DDevolvPtsLeftkdotOz - DDevolvPtsLeftkOzAlldot);

DDevolvPtsLeftkOzVScOz          = Transpose[{DDevolvPtsLeftkOz,DDevolvPtsLeftcOz}];
DDevolvPtsLeftkOzVScdotOc       = Transpose[{DDevolvPtsLeftkOz,DDevolvPtsLeftcdotOc}];
DDevolvPtsLeftkOzVSkOzAlldot    = Transpose[{DDevolvPtsLeftkOz,DDevolvPtsLeftkOzAlldot}];
DDevolvPtsLeftkOzVSkdotOk       = Transpose[{DDevolvPtsLeftkOz,DDevolvPtsLeftkdotOk}];
DDevolvPtsLeftkOzVSzdotOz       = Transpose[{DDevolvPtsLeftkOz,DDevolvPtsLeftzdotOz}];
DDevolvPtsLeftkOzVScdotOcAlldot = Transpose[{DDevolvPtsLeftkOz,DDevolvPtsLeftcdotOcAlldot}];
DDevolvPtsLeftkOzVSsOy          = Transpose[{DDevolvPtsLeftkOz,DDevolvPtsLeftsOy}];

Clear[DDevolvFuncLeft2DcOzVScdotOc];
Clear[DDevolvFuncLeft2DcdotOcVScOz];
Clear[DDevolvFuncLeft2DcdotOcVScOk];
Clear[DDevolvFuncLeft2DcdotOcVSkOz];
Clear[DDevolvFuncLeft2DcOzVScOk];
Clear[DDevolvFuncLeft2DcOzVSkOz];

Clear[DDevolvFuncLeft2DkOzVScOz];
Clear[DDevolvFuncLeft2DkOzVScdotOc];
Clear[DDevolvFuncLeft2DkOzVSkOzAlldot];
Clear[DDevolvFuncLeft2DkOzVSkdotOk];
Clear[DDevolvFuncLeft2DkOzVSzdotOz];
Clear[DDevolvFuncLeft2DkOzVScdotOcAlldot];
Clear[DDevolvFuncLeft2DkOzVSsOy];

DDevolvFuncLeft2DcOzVScdotOc = Interpolation[DDevolvPtsLeftcOzVScdotOc];
DDevolvFuncLeft2DcdotOcVScOk = Interpolation[DDevolvPtsLeftcdotOcVScOk];
DDevolvFuncLeft2DcdotOcVScOz = Interpolation[DDevolvPtsLeftcdotOcVScOz];
DDevolvFuncLeft2DcdotOcVSkOz = Interpolation[DDevolvPtsLeftcdotOcVSkOz];
DDevolvFuncLeft2DcOzVScOk    = Interpolation[DDevolvPtsLeftcOzVScOk];
DDevolvFuncLeft2DcOzVSkOz    = Interpolation[DDevolvPtsLeftcOzVSkOz];
DDevolvFuncLeft2DkOzVScOz    = Interpolation[DDevolvPtsLeftkOzVScOz];

DDevolvFuncLeft2DkOzVScOz          = Interpolation[DDevolvPtsLeftkOzVScOz         ];
DDevolvFuncLeft2DkOzVScdotOc       = Interpolation[DDevolvPtsLeftkOzVScdotOc      ];
DDevolvFuncLeft2DkOzVSkOzAlldot    = Interpolation[DDevolvPtsLeftkOzVSkOzAlldot   ];
DDevolvFuncLeft2DkOzVSkdotOk       = Interpolation[DDevolvPtsLeftkOzVSkdotOk      ];
DDevolvFuncLeft2DkOzVSzdotOz       = Interpolation[DDevolvPtsLeftkOzVSzdotOz      ];
DDevolvFuncLeft2DkOzVScdotOcAlldot = Interpolation[DDevolvPtsLeftkOzVScdotOcAlldot];
DDevolvFuncLeft2DkOzVSsOy          = Interpolation[DDevolvPtsLeftkOzVSsOy];

TDDevolvPtsRight3D = Transpose[DDevolvPtsRight3D];

DDevolvPtsRightcOz      = TDDevolvPtsRight3D[[1]];
DDevolvPtsRightcdotOc   = TDDevolvPtsRight3D[[2]];
DDevolvPtsRightkOz      = TDDevolvPtsRight3D[[3]];
DDevolvPtsRightcOk      = TDDevolvPtsRight3D[[1]]/TDDevolvPtsRight3D[[3]];
DDevolvPtsRightkdotOk   = (A - delta) - DDevolvPtsRightcOk;
DDevolvPtsRightsOy      = 1- DDevolvPtsRightcOk/A;

DDevolvPtsRight3D     = Transpose[{DDevolvPtsRightcOz,DDevolvPtsRightcdotOc,DDevolvPtsRightkOz}];

DDevolvRightcOzMin       = Min[DDevolvPtsRightcOz];
DDevolvRightcOzMax       = Max[DDevolvPtsRightcOz];
DDevolvRightcdotOcMin    = Min[DDevolvPtsRightcdotOc];
DDevolvRightcdotOcMax    = Max[DDevolvPtsRightcdotOc];
DDevolvRightcOkMin       = Min[DDevolvPtsRightcOk];
DDevolvRightcOkMax       = Max[DDevolvPtsRightcOk];
DDevolvRightkOzMin       = Min[DDevolvPtsRightkOz];
DDevolvRightkOzMax       = Max[DDevolvPtsRightkOz];
DDevolvRightkOzAlldotMin = Min[DDevolvPtsRightkOzAlldot];
DDevolvRightkOzAlldotMax = Max[DDevolvPtsRightkOzAlldot];
DDevolvRightcdotOcAlldotMin = Min[DDevolvPtsRightcdotOcAlldot];
DDevolvRightcdotOcAlldotMax = Max[DDevolvPtsRightcdotOcAlldot];
DDevolvRightcdotOcAlldotMin = Min[DDevolvPtsRightcdotOcAlldot];
DDevolvRightcdotOcAlldotMax = Max[DDevolvPtsRightcdotOcAlldot];
DDevolvRightkdotOzMin    = Min[DDevolvPtsRightkdotOz];
DDevolvRightkdotOzMax    = Max[DDevolvPtsRightkdotOz];
DDevolvRightzdotOzMin    = Min[DDevolvPtsRightzdotOz];
DDevolvRightzdotOzMax    = Max[DDevolvPtsRightzdotOz];
DDevolvRightsOyMin       = Min[DDevolvPtsRightsOy];
DDevolvRightsOyMax       = Max[DDevolvPtsRightsOy];

DDevolvPtsRightcOzVScdotOc = Transpose[{DDevolvPtsRightcOz,DDevolvPtsRightcdotOc}];
DDevolvPtsRightcdotOcVScOk = Transpose[{DDevolvPtsRightcdotOc,DDevolvPtsRightcOk}];
DDevolvPtsRightcdotOcVScOz = Transpose[{DDevolvPtsRightcdotOc,DDevolvPtsRightcOz}];
DDevolvPtsRightcdotOcVSkOz = Transpose[{DDevolvPtsRightcdotOc,DDevolvPtsRightkOz}];
DDevolvPtsRightcOzVScOk    = Transpose[{DDevolvPtsRightcOz,DDevolvPtsRightcOk}];
DDevolvPtsRightcOzVSkOz    = Transpose[{DDevolvPtsRightcOz,DDevolvPtsRightkOz}];

DDevolvPtsRightkOzAlldot    = Map[kOzAlldotListForm,DDevolvPtsRightcOzVSkOz];
DDevolvPtsRightcdotOcAlldot = Map[cdotOcAlldotListForm,DDevolvPtsRightcOzVScdotOc];

(* Note that zdotOz = 1/(k/z) * (kdotOz - kOzAlldot) and kdotOz = kdotOk * kOz *)
DDevolvPtsRightkdotOz = DDevolvPtsRightkdotOk * DDevolvPtsRightkOz;
DDevolvPtsRightzdotOz = (1/DDevolvPtsRightkOz) (DDevolvPtsRightkdotOz - DDevolvPtsRightkOzAlldot);

DDevolvPtsRightkOzVScOz          = Transpose[{DDevolvPtsRightkOz,DDevolvPtsRightcOz}];
DDevolvPtsRightkOzVScdotOc       = Transpose[{DDevolvPtsRightkOz,DDevolvPtsRightcdotOc}];
DDevolvPtsRightkOzVSkOzAlldot    = Transpose[{DDevolvPtsRightkOz,DDevolvPtsRightkOzAlldot}];
DDevolvPtsRightkOzVSkdotOk       = Transpose[{DDevolvPtsRightkOz,DDevolvPtsRightkdotOk}];
DDevolvPtsRightkOzVSzdotOz       = Transpose[{DDevolvPtsRightkOz,DDevolvPtsRightzdotOz}];
DDevolvPtsRightkOzVScdotOcAlldot = Transpose[{DDevolvPtsRightkOz,DDevolvPtsRightcdotOcAlldot}];
DDevolvPtsRightkOzVSsOy          = Transpose[{DDevolvPtsRightkOz,DDevolvPtsRightsOy      }];

Clear[DDevolvFuncRight2DcOzVScdotOc];
Clear[DDevolvFuncRight2DcdotOcVScOz];
Clear[DDevolvFuncRight2DcdotOcVScOk];
Clear[DDevolvFuncRight2DcdotOcVSkOz];
Clear[DDevolvFuncRight2DcOzVScOk];
Clear[DDevolvFuncRight2DcOzVSkOz];

Clear[DDevolvFuncRight2DkOzVScOz];
Clear[DDevolvFuncRight2DkOzVScdotOc];
Clear[DDevolvFuncRight2DkOzVSkOzAlldot];
Clear[DDevolvFuncRight2DkOzVSkdotOk];
Clear[DDevolvFuncRight2DkOzVSzdotOz];
Clear[DDevolvFuncRight2DkOzVScdotOcAlldot];
Clear[DDevolvFuncRight2DkOzVSsOy];

DDevolvFuncRight2DcOzVScdotOc = Interpolation[DDevolvPtsRightcOzVScdotOc];
DDevolvFuncRight2DcdotOcVScOk = Interpolation[DDevolvPtsRightcdotOcVScOk];
DDevolvFuncRight2DcdotOcVScOz = Interpolation[DDevolvPtsRightcdotOcVScOz];
DDevolvFuncRight2DcdotOcVSkOz = Interpolation[DDevolvPtsRightcdotOcVSkOz];
DDevolvFuncRight2DcOzVScOk    = Interpolation[DDevolvPtsRightcOzVScOk];
DDevolvFuncRight2DcOzVSkOz    = Interpolation[DDevolvPtsRightcOzVSkOz];
DDevolvFuncRight2DkOzVScOz    = Interpolation[DDevolvPtsRightkOzVScOz];

DDevolvFuncRight2DkOzVScOz          = Interpolation[DDevolvPtsRightkOzVScOz         ];
DDevolvFuncRight2DkOzVScdotOc       = Interpolation[DDevolvPtsRightkOzVScdotOc      ];
DDevolvFuncRight2DkOzVSkOzAlldot    = Interpolation[DDevolvPtsRightkOzVSkOzAlldot   ];
DDevolvFuncRight2DkOzVSkdotOk       = Interpolation[DDevolvPtsRightkOzVSkdotOk      ];
DDevolvFuncRight2DkOzVSzdotOz       = Interpolation[DDevolvPtsRightkOzVSzdotOz      ];
DDevolvFuncRight2DkOzVScdotOcAlldot = Interpolation[DDevolvPtsRightkOzVScdotOcAlldot];
DDevolvFuncRight2DkOzVSsOy          = Interpolation[DDevolvPtsRightkOzVSsOy];

DDevolvPtskOz          = Join[DDevolvPtsLeftkOz,DDevolvPtsRightkOz];
DDevolvPtscOz          = Join[DDevolvPtsLeftcOz,DDevolvPtsRightcOz];
DDevolvPtscdotOc       = Join[DDevolvPtsLeftcdotOc,DDevolvPtsRightcdotOc];
DDevolvPtskOzAlldot    = Join[DDevolvPtsLeftkOzAlldot,DDevolvPtsRightkOzAlldot];
DDevolvPtskdotOk       = Join[DDevolvPtsLeftkdotOk,DDevolvPtsRightkdotOk];
DDevolvPtszdotOz       = Join[DDevolvPtsLeftzdotOz,DDevolvPtsRightzdotOz];
DDevolvPtscdotOcAlldot = Join[DDevolvPtsLeftcdotOcAlldot,DDevolvPtsRightcdotOcAlldot];
DDevolvPtssOy          = Join[DDevolvPtsLeftsOy,DDevolvPtsRightsOy];

DDevolvPtscOk          = Join[DDevolvPtsLeftcOk,DDevolvPtsRightcOk];
DDevolvPtskdotOk       = Join[DDevolvPtsLeftkdotOk,DDevolvPtsRightkdotOk];
DDevolvPtssOy          = Join[DDevolvPtsLeftsOy,DDevolvPtsRightsOy];

DMaxPtskOz           = Max[DDevolvPtskOz         ];
DMaxPtscOz           = Max[DDevolvPtscOz         ];
DMaxPtscdotOc        = Max[DDevolvPtscdotOc      ];
DMaxPtskOzAlldot     = Max[DDevolvPtskOzAlldot   ];
DMaxPtskdotOk        = Max[DDevolvPtskdotOk      ];
DMaxPtszdotOz        = Max[DDevolvPtszdotOz      ];
DMaxPtscdotOcAlldot  = Max[DDevolvPtscdotOcAlldot];
DMaxPtssOy           = Max[DDevolvPtssOy         ];

DMinPtskOz           = Min[DDevolvPtskOz         ];
DMinPtscOz           = Min[DDevolvPtscOz         ];
DMinPtscdotOc        = Min[DDevolvPtscdotOc      ];
DMinPtskOzAlldot     = Min[DDevolvPtskOzAlldot   ];
DMinPtskdotOk        = Min[DDevolvPtskdotOk      ];
DMinPtszdotOz        = Min[DDevolvPtszdotOz      ];
DMinPtscdotOcAlldot  = Min[DDevolvPtscdotOcAlldot];
DMinPtssOy           = Min[DDevolvPtssOy         ];

DDevolvPtscOzVScdotOc = Transpose[{DDevolvPtscOz,DDevolvPtscdotOc}];
DDevolvPtscdotOcVScOk = Transpose[{DDevolvPtscdotOc,DDevolvPtscOk}];
DDevolvPtscdotOcVScOz = Transpose[{DDevolvPtscdotOc,DDevolvPtscOz}];
DDevolvPtscdotOcVSkOz = Transpose[{DDevolvPtscdotOc,DDevolvPtskOz}];
DDevolvPtscOzVScOk    = Transpose[{DDevolvPtscOz,DDevolvPtscOk}];
DDevolvPtscOzVSkOz    = Transpose[{DDevolvPtscOz,DDevolvPtskOz}];

DDevolvPtskOzVScOz          = Sort[Join[DDevolvPtsLeftkOzVScOz,DDevolvPtsRightkOzVScOz]]                  ;
DDevolvPtskOzVScdotOc       = Sort[Join[DDevolvPtsLeftkOzVScdotOc,DDevolvPtsRightkOzVScdotOc]]            ;
DDevolvPtskOzVSkOzAlldot    = Sort[Join[DDevolvPtsLeftkOzVSkOzAlldot,DDevolvPtsRightkOzVSkOzAlldot]]      ;
DDevolvPtskOzVSkdotOk       = Sort[Join[DDevolvPtsLeftkOzVSkdotOk,DDevolvPtsRightkOzVSkdotOk]]            ;
DDevolvPtskOzVSzdotOz       = Sort[Join[DDevolvPtsLeftkOzVSzdotOz,DDevolvPtsRightkOzVSzdotOz]]            ;
DDevolvPtskOzVScdotOcAlldot = Sort[Join[DDevolvPtsLeftkOzVScdotOcAlldot,DDevolvPtsRightkOzVScdotOcAlldot]];
DDevolvPtskOzVSsOy          = Sort[Join[DDevolvPtsLeftkOzVSsOy,DDevolvPtsRightkOzVSsOy]]                  ;

Clear[DDevolvFunc2DcOzVScdotOc ];
Clear[DDevolvFunc2DcdotOcVScOk ];
Clear[DDevolvFunc2DcdotOcVScOz ];
Clear[DDevolvFunc2DcdotOcVSkOz ];
Clear[DDevolvFunc2DcOzVScOk    ];
Clear[DDevolvFunc2DcOzVSkOz    ];
Clear[DDevolvFunc2DkOzVScOz    ];

DDevolvFunc2DcOzVScdotOc = Interpolation[DDevolvPtscOzVScdotOc];
DDevolvFunc2DcdotOcVScOk = Interpolation[DDevolvPtscdotOcVScOk];
DDevolvFunc2DcdotOcVScOz = Interpolation[DDevolvPtscdotOcVScOz];
DDevolvFunc2DcdotOcVSkOz = Interpolation[DDevolvPtscdotOcVSkOz];
DDevolvFunc2DcOzVScOk    = Interpolation[DDevolvPtscOzVScOk];
DDevolvFunc2DcOzVSkOz    = Interpolation[DDevolvPtscOzVSkOz];
DDevolvFunc2DkOzVScOz    = Interpolation[DDevolvPtskOzVScOz];

Clear[DDevolvFunc2DkOzVScOz];
Clear[DDevolvFunc2DkOzVScdotOc];
Clear[DDevolvFunc2DkOzVSkOzAlldot];
Clear[DDevolvFunc2DkOzVSkdotOk];
Clear[DDevolvFunc2DkOzVSzdotOz];
Clear[DDevolvFunc2DkOzVScdotOcAlldot];
Clear[DDevolvFunc2DkOzVSsOy];

DDevolvFunc2DkOzVScOz          = Interpolation[DDevolvPtskOzVScOz         ];
DDevolvFunc2DkOzVScdotOc       = Interpolation[DDevolvPtskOzVScdotOc      ];
DDevolvFunc2DkOzVSkOzAlldot    = Interpolation[DDevolvPtskOzVSkOzAlldot   ];
DDevolvFunc2DkOzVSkdotOk       = Interpolation[DDevolvPtskOzVSkdotOk      ];
DDevolvFunc2DkOzVSzdotOz       = Interpolation[DDevolvPtskOzVSzdotOz      ];
DDevolvFunc2DkOzVScdotOcAlldot = Interpolation[DDevolvPtskOzVScdotOcAlldot];
DDevolvFunc2DkOzVSsOy          = Interpolation[DDevolvPtskOzVSsOy         ];


